@@ -21,14 +21,14 @@ class MegaFlow2D(Dataset):
         split_scheme: 'full', 'circle', 'ellipse', 'mixed'
         split_ratio: defult set as [0.5, 0.5] for circle and ellipse respectively
     """
-    def __init__(self, root, download, transform=None, pre_transform=None, split_scheme='mixed', split_ratio=None):
+    def __init__(self, root, download, transform, pre_transform, split_scheme='mixed', split_ratio=None):
         self._indices = None
         self.root = root
         # self.split = split
         self.transforms = transform
         self.pre_transform = pre_transform
         if download:
-            self.download()
+            self.download(root)
         self.raw_data_dir = os.path.join(self.root, 'raw')
         self.processed_data_dir = os.path.join(self.root, 'processed')
         self.data_list = self.processed_file_names
